@@ -10,13 +10,17 @@ import subprocess
 
 from scriptengine.tasks.base import Task
 from scriptengine.tasks.base.timing import timed_runner
-from scriptengine.exceptions import ScriptEngineStopException
+from scriptengine.exceptions import ScriptEngineTaskRunError
 
 
 class Command(Task):
     """Command task, executes a command in a shell"""
-    def __init__(self, parameters):
-        super().__init__(__name__, parameters, ["name"])
+
+    _required_arguments = ('name', )
+
+    def __init__(self, arguments):
+        Command.check_arguments(arguments)
+        super().__init__(arguments)
 
     @timed_runner
     def run(self, context):
@@ -36,17 +40,20 @@ class Command(Task):
 
         stdout = self.getarg('stdout', default=None)
         try:
-            result = subprocess.run(map(str, [command]+args),
-                                    stdout=subprocess.PIPE if stdout is not None else None,
-                                    cwd=cwd,
-                                    check=True)
+            result = subprocess.run(
+                        map(str, [command]+args),
+                        stdout=subprocess.PIPE if stdout is not None else None,
+                        cwd=cwd,
+                        check=True)
         except subprocess.CalledProcessError as error:
+            msg = (f'Command "{self.name}" returned '
+                   f'error code {error.returncode}')
             if self.getarg('ignore_error', context, default=False):
-                self.log_warning(f"{self.name} returned error code {error.returncode}")
+                self.log_warning(msg)
             else:
-                self.log_error(f"{self.name} returned error code {error.returncode}")
-                raise ScriptEngineStopException("Stopping ScriptEngine after nonzero "
-                                                "exit code in command task")
+                self.log_error(msg)
+                raise ScriptEngineTaskRunError(msg)
         else:
             if stdout is not None:
-                context[stdout] = [binary.decode("UTF-8") for binary in result.stdout.splitlines()]
+                context[stdout] = [binary.decode("UTF-8")
+                                   for binary in result.stdout.splitlines()]
